@@ -129,9 +129,10 @@ class Surface:
             )
 
     def getIvFromStrikeAndDte(self, strike, dte):
-        curves = sorted(self.curves, key=lambda x: x.dte)
+        curves = sorted(self.curves, key=lambda x: x.dte, ascending=True)
         lowestIv = lowestDte = highestIv = highestDte = 0
-        for idx in range(len(curves))[::-1]:
+        # print([x.dte for x in curves])
+        for idx in range(len(curves)):
             if dte < curves[idx].dte:
                 lowestIv = curves[idx].getIvFromStrike(strike)
                 lowestDte = curves[idx].dte
@@ -210,7 +211,7 @@ class Curve:
             )
 
     def getIvFromStrike(self, strike):
-        assert strike > 0
+        assert strike >= 0
         lowestIv = lowestStrike = highestIv = highestStrike = 0
         # Reverse the strikes if call.
         should_reverse = -1 if self.putCall == "C" else 1
@@ -223,16 +224,15 @@ class Curve:
                 highestIv = self.markIvs[idx]
                 highestStrike = self.strikes[idx]
 
-        print(
-            self.strikes,
-            highestIv,
-            highestStrike,
-            lowestIv,
-            lowestStrike,
-            self.putCall,
-            should_reverse,
-        )
-        # print(self.strikes, self.markIvs)
+        # print(
+        #     self.strikes,
+        #     highestIv,
+        #     highestStrike,
+        #     lowestIv,
+        #     lowestStrike,
+        #     self.putCall,
+        #     should_reverse,
+        # )
         if lowestStrike == 0:
             return self.markIvs[idx]
         elif highestStrike == 0:
