@@ -3,15 +3,31 @@ import pandas as pd
 from datetime import datetime
 
 from utils import options
-from .options import Surface, Curve
+from .options import Surface, Curve, find_strike
 
 df = pd.read_csv("btc_call.csv")
 df2 = pd.read_csv("btc_put.csv")
 df3 = pd.read_csv("sol_put.csv")
 
-CALL = Surface(df, datetime(2022, 1, 1), "C", "BTC", 1)
-PUT = Surface(df2, datetime(2022, 1, 1), "P", "BTC", 1)
-SOLPUT = Surface(df3, datetime(2022, 7, 18), "P", "SOL", 1)
+CALL = Surface(df, datetime(2022, 1, 1), "C", "BTC", 20000)
+PUT = Surface(df2, datetime(2022, 1, 1), "P", "BTC", 20000)
+SOLPUT = Surface(df3, datetime(2022, 7, 18), "P", "SOL", 40)
+
+
+@pytest.mark.parametrize(
+    "strike, delta",
+    [
+        (
+            1.0,
+            0.1,
+        ),
+    ],
+)
+def test_getIvFromStrike(strike, delta):
+    iv = SOLPUT.curves[0].getIvFromDelta(delta)
+    strike = find_strike("P", SOLPUT.spot, 7 / 365, 0, iv / 100, delta)
+    print(SOLPUT.spot, strike, delta, iv)
+    assert iv
 
 
 @pytest.mark.parametrize(
@@ -73,3 +89,10 @@ def test_getIvFromStrike_mid_put(strike):
     iv = PUT.curves[0].getIvFromStrike(strike)
     assert iv == 75.036
     print(strike, iv)
+
+
+def test_find_strike():
+    print(PUT.curves[0].getIvFromStrike(20000))
+    print(PUT.curves[0].getIvFromDelta(0.4))
+    print()
+    assert False
